==> wawa-service-api-0.0.8-20171031.130549-2-sources.jar: cn/com/wawa/service/api/dto/UserCatchedWawaDto.java <==
package cn.com.wawa.service.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by gyf .
 * 2017/10/30 .
 */
public class UserCatchedWawaDto implements Serializable {

    private static final long serialVersionUID = -8856117067698543281L;

    private Long id;

    private Long userId;

    private Long deliveryOrderId;

    private Long orderId;

    private Integer quantity;

    private Long catcherId;

    private Long wawaId;

    private Integer winOrderStatus;

    private String wawaName;

    private String indexImage;

    private Date gmtCreate;

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getIndexImage() {
        return indexImage;
    }

    public void setIndexImage(String indexImage) {
        this.indexImage = indexImage;
    }

    public String getWawaName() {
        return wawaName;
    }

    public void setWawaName(String wawaName) {
        this.wawaName = wawaName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getDeliveryOrderId() {
        return deliveryOrderId;
    }

    public void setDeliveryOrderId(Long deliveryOrderId) {
        this.deliveryOrderId = deliveryOrderId;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public Long getCatcherId() {
        return catcherId;
    }

    public void setCatcherId(Long catcherId) {
        this.catcherId = catcherId;
    }

    public Long getWawaId() {
        return wawaId;
    }

    public void setWawaId(Long wawaId) {
        this.wawaId = wawaId;
    }

    public Integer getWinOrderStatus() {
        return winOrderStatus;
    }

    public void setWinOrderStatus(Integer winOrderStatus) {
        this.winOrderStatus = winOrderStatus;
    }
}

==> wawa-service-api-0.0.20-20180116.071249-8-sources.jar: cn/com/wawa/service/api/dto/UserCatchedWawaDto.java <==
package cn.com.wawa.service.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by gyf .
 * 2017/10/30 .
 */
public class UserCatchedWawaDto implements Serializable {

    private static final long serialVersionUID = -8856117067698543281L;

    private Long id;

    private Long userId;

    private Long deliveryOrderId;

    private Long orderId;

    private Integer quantity;

    private Long catcherId;

    private Long wawaId;

    private Integer winOrderStatus;

    private String wawaName;

    private String indexImage;

    private Date gmtCreate;

    private String deliveryNum;

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getIndexImage() {
        return indexImage;
    }

    public void setIndexImage(String indexImage) {
        this.indexImage = indexImage;
    }

    public String getWawaName() {
        return wawaName;
    }

    public void setWawaName(String wawaName) {
        this.wawaName = wawaName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getDeliveryOrderId() {
        return deliveryOrderId;
    }

    public void setDeliveryOrderId(Long deliveryOrderId) {
        this.deliveryOrderId = deliveryOrderId;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public Long getCatcherId() {
        return catcherId;
    }

    public void setCatcherId(Long catcherId) {
        this.catcherId = catcherId;
    }

    public Long getWawaId() {
        return wawaId;
    }

    public void setWawaId(Long wawaId) {
        this.wawaId = wawaId;
    }

    public Integer getWinOrderStatus() {
        return winOrderStatus;
    }

    public void setWinOrderStatus(Integer winOrderStatus) {
        this.winOrderStatus = winOrderStatus;
    }

    public String getDeliveryNum() {
        return deliveryNum;
    }

    public void setDeliveryNum(String deliveryNum) {
        this.deliveryNum = deliveryNum;
    }
}
